from ximea import xiapi
import cv2      

#create instance for first connected camera 
cam = xiapi.Camera()

#start communication
print('Opening first camera...')
cam.open_device()

#settings
cam.set_imgdataformat('XI_MONO16')
cam.set_exposure(50000)

cam.enable_auto_wb()

#create instance of Image to store image data and metadata
img = xiapi.Image()

#start data acquisition
print('Starting data acquisition...')
cam.start_acquisition()

#get data and pass them from camera to img
cam.get_image(img)

#create numpy array with data from camera. Dimensions of array are determined
#by imgdataformat
data = img.get_image_data_numpy()

#stop data acquisition
print('Stopping acquisition...')
cam.stop_acquisition()

#stop communication
cam.close_device()

#show acquired image
print('Drawing image...')
h, w = data.shape[:2] # Get image dimensions
max_w, max_h = 1920, 1280 # Maximum window size
scale = min(max_w / w, max_h / h) # Calculate scale factor
win_w, win_h = int(w * scale), int(h * scale) # Resized dimensions

win = 'OpenCV 16bit example'
cv2.namedWindow(win, cv2.WINDOW_NORMAL | cv2.WINDOW_KEEPRATIO)  # Resizable
cv2.resizeWindow(win, win_w, win_h)  # Risezing window and image
cv2.imshow(win, 20*data)
cv2.waitKey(0)
cv2.destroyAllWindows()

print('Done.')



from ximea import xiapi
import cv2
import time


def get_camera_basic_info(cam: xiapi.Camera) -> str:
    """
    The function returns basic information about the camera and API version.
    
    :return device name, serial number, sensor serial number, api version:
    """
    if cam.is_isexist:
        name = cam.get_device_name().decode("UTF-8")
        sn = cam.get_device_sn().decode("UTF-8")
        try:
            sensor_sn = cam.get_device_sens_sn().decode("UTF-8")
        except Exception as e:
            sensor_sn = e
        api_version = cam.get_api_version().decode("UTF-8")

        return f"""
        Device Name:\t\t\t{name}
        Serial Number:\t\t\t{sn}
        Sensor Serial Number:\t\t{sensor_sn}
        Api Version:\t\t\t{api_version}
        """

#create instance for first connected camera 
cam = xiapi.Camera()

#start communication
print('Opening first camera...')
cam.open_device()
info = get_camera_basic_info(cam)
print(info)

#settings
cam.set_exposure(20000)

cam.enable_auto_wb()

#create instance of Image to store image data and metadata
img = xiapi.Image()

#start data acquisition
print('Starting data acquisition...')
cam.start_acquisition()

try:
    print('Starting video. Press ESC to exit.')
    t0 = time.time()
    while True:
        #get data and pass them from camera to img
        cam.get_image(img)

        #create numpy array with data from camera. Dimensions of the array are 
        #determined by imgdataformat
        data = img.get_image_data_numpy()

        #show acquired image with time since the beginning of acquisition
        font = cv2.FONT_HERSHEY_SIMPLEX
        text = '{:5.2f}'.format(time.time()-t0)
        cv2.putText(
            data, text, (900,150), font, 4, (255, 255, 255), 2
            )
        h, w = data.shape[:2] # Get image dimensions
        max_w, max_h = 1920, 1280 # Maximum window size
        scale = min(max_w / w, max_h / h) # Calculate scale factor
        win_w, win_h = int(w * scale), int(h * scale) # Resized dimensions

        win = 'OpenCV video example'
        cv2.namedWindow(win, cv2.WINDOW_NORMAL | cv2.WINDOW_KEEPRATIO)  # Resizable
        cv2.resizeWindow(win, win_w, win_h)  # Risezing window and image
        cv2.imshow(win, data)

        key = cv2.waitKey(1)
        if key == 27:
            break
        
except KeyboardInterrupt:
    cv2.destroyAllWindows()

#stop data acquisition
print('Stopping acquisition...')
cam.stop_acquisition()

#stop communication
cam.close_device()

print('Done.')



from ximea import xiapi

CAMERAS_ON_SAME_CONTROLLER = 2

#create instance for cameras
cam1 = xiapi.Camera(dev_id=0)
cam2 = xiapi.Camera(dev_id=1)

#start communication
print('Opening cameras...')
cam1.open_device()
cam2.open_device()

#set interface data rate
interface_data_rate=cam1.get_limit_bandwidth();
camera_data_rate = int(interface_data_rate / CAMERAS_ON_SAME_CONTROLLER) ;

#set data rate
cam1.set_limit_bandwidth(camera_data_rate);
cam2.set_limit_bandwidth(camera_data_rate);

#print device serial numbers
print('Camera 1 serial number: ' + str(cam1.get_device_sn()))
print('Camera 2 serial number: ' + str(cam2.get_device_sn()))

#settings
cam1.set_exposure(10000)
print('Cam1: Exposure was set to %i us' %cam1.get_exposure())
cam2.set_exposure(10000)
print('Cam2: Exposure was set to %i us' %cam2.get_exposure())


#create instance of Image to store image data and metadata
img1 = xiapi.Image()
img2 = xiapi.Image()

#start data acquisition
print('Starting data acquisition...\n')
cam1.start_acquisition()
cam2.start_acquisition()

#get data and pass them from cameras to img
cam1.get_image(img1)
cam2.get_image(img2)

#get raw data from cameras
#for Python2.x function returns string
#for Python3.x function returns bytes
data_raw1 = img1.get_image_data_raw()
data_raw2 = img2.get_image_data_raw()

#transform data to list
data1 = list(data_raw1)
data2 = list(data_raw2)

#print image data and metadata
print('Cam1: image (' + str(img1.width) + 'x' + str(img1.height) + ') received from camera.')
print('First 10 pixels: ' + str(data1[:10]) + '\n')

print('Cam2: image (' + str(img2.width) + 'x' + str(img2.height) + ') received from camera.')
print('First 10 pixels: ' + str(data2[:10]))
print('\n')

#stop data acquisition
print('Cam1: Stopping acquisition...')
cam1.stop_acquisition()
print('Cam2: Stopping acquisition...')
cam2.stop_acquisition()

#stop communication
cam1.close_device()
cam2.close_device()

print('Done.')



